.. _spider_servustv.com:

servustv.com
------------
Videos shown on `ServusTV <https://www.servustv.com>`_ in the next two weeks.

Configuration
~~~~~~~~~~~~~
Add ``servustv.com`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     servustv.com
